==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/CustomizedAcceleratorPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.CustomizedAcceleratorPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Customized accelerator properties payload
 * @property acceleratorTags
 * @property description
 * @property displayName
 * @property gitRepository
 * @property iconUrl
 */
public data class CustomizedAcceleratorPropertiesArgs(
    public val acceleratorTags: Output<List<String>>? = null,
    public val description: Output<String>? = null,
    public val displayName: Output<String>? = null,
    public val gitRepository: Output<AcceleratorGitRepositoryArgs>,
    public val iconUrl: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.CustomizedAcceleratorPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.appplatform.inputs.CustomizedAcceleratorPropertiesArgs =
        com.pulumi.azurenative.appplatform.inputs.CustomizedAcceleratorPropertiesArgs.builder()
            .acceleratorTags(acceleratorTags?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .description(description?.applyValue({ args0 -> args0 }))
            .displayName(displayName?.applyValue({ args0 -> args0 }))
            .gitRepository(gitRepository.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .iconUrl(iconUrl?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CustomizedAcceleratorPropertiesArgs].
 */
@PulumiTagMarker
public class CustomizedAcceleratorPropertiesArgsBuilder internal constructor() {
    private var acceleratorTags: Output<List<String>>? = null

    private var description: Output<String>? = null

    private var displayName: Output<String>? = null

    private var gitRepository: Output<AcceleratorGitRepositoryArgs>? = null

    private var iconUrl: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("tigvcespnvumfmam")
    public suspend fun acceleratorTags(`value`: Output<List<String>>) {
        this.acceleratorTags = value
    }

    @JvmName("jrvvrcucpwtkihap")
    public suspend fun acceleratorTags(vararg values: Output<String>) {
        this.acceleratorTags = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("wigwugbqpbdmrekr")
    public suspend fun acceleratorTags(values: List<Output<String>>) {
        this.acceleratorTags = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("nfciyoitpgqpicje")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value
     */
    @JvmName("becjesnodlsyneey")
    public suspend fun displayName(`value`: Output<String>) {
        this.displayName = value
    }

    /**
     * @param value
     */
    @JvmName("hkmerfrexkgwlrus")
    public suspend fun gitRepository(`value`: Output<AcceleratorGitRepositoryArgs>) {
        this.gitRepository = value
    }

    /**
     * @param value
     */
    @JvmName("ylvgekroewbcygoy")
    public suspend fun iconUrl(`value`: Output<String>) {
        this.iconUrl = value
    }

    /**
     * @param value
     */
    @JvmName("nibcdtiywrmlaekv")
    public suspend fun acceleratorTags(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.acceleratorTags = mapped
    }

    /**
     * @param values
     */
    @JvmName("pxxmordeewfbhypg")
    public suspend fun acceleratorTags(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.acceleratorTags = mapped
    }

    /**
     * @param value
     */
    @JvmName("qgorhymwtvtbruws")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value
     */
    @JvmName("ktmtfysnvqulhkip")
    public suspend fun displayName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.displayName = mapped
    }

    /**
     * @param value
     */
    @JvmName("nvvsegblgsrhpmrd")
    public suspend fun gitRepository(`value`: AcceleratorGitRepositoryArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.gitRepository = mapped
    }

    /**
     * @param argument
     */
    @JvmName("fhyvehtpkufrdval")
    public suspend
    fun gitRepository(argument: suspend AcceleratorGitRepositoryArgsBuilder.() -> Unit) {
        val toBeMapped = AcceleratorGitRepositoryArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.gitRepository = mapped
    }

    /**
     * @param value
     */
    @JvmName("hbwuhefxdpsqeris")
    public suspend fun iconUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.iconUrl = mapped
    }

    internal fun build(): CustomizedAcceleratorPropertiesArgs = CustomizedAcceleratorPropertiesArgs(
        acceleratorTags = acceleratorTags,
        description = description,
        displayName = displayName,
        gitRepository = gitRepository ?: throw PulumiNullFieldException("gitRepository"),
        iconUrl = iconUrl,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/CustomizedAcceleratorPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.CustomizedAcceleratorPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Customized accelerator properties payload
 * @property acceleratorTags
 * @property description
 * @property displayName
 * @property gitRepository
 * @property iconUrl
 */
public data class CustomizedAcceleratorPropertiesArgs(
    public val acceleratorTags: Output<List<String>>? = null,
    public val description: Output<String>? = null,
    public val displayName: Output<String>? = null,
    public val gitRepository: Output<AcceleratorGitRepositoryArgs>,
    public val iconUrl: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.CustomizedAcceleratorPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.appplatform.inputs.CustomizedAcceleratorPropertiesArgs =
        com.pulumi.azurenative.appplatform.inputs.CustomizedAcceleratorPropertiesArgs.builder()
            .acceleratorTags(acceleratorTags?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .description(description?.applyValue({ args0 -> args0 }))
            .displayName(displayName?.applyValue({ args0 -> args0 }))
            .gitRepository(gitRepository.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .iconUrl(iconUrl?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CustomizedAcceleratorPropertiesArgs].
 */
@PulumiTagMarker
public class CustomizedAcceleratorPropertiesArgsBuilder internal constructor() {
    private var acceleratorTags: Output<List<String>>? = null

    private var description: Output<String>? = null

    private var displayName: Output<String>? = null

    private var gitRepository: Output<AcceleratorGitRepositoryArgs>? = null

    private var iconUrl: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("bapgjhbjfiuawkhg")
    public suspend fun acceleratorTags(`value`: Output<List<String>>) {
        this.acceleratorTags = value
    }

    @JvmName("rdstcmyxpdxviywv")
    public suspend fun acceleratorTags(vararg values: Output<String>) {
        this.acceleratorTags = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("rsrfbytoxnhqnohh")
    public suspend fun acceleratorTags(values: List<Output<String>>) {
        this.acceleratorTags = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("fivtovsuovlgxtjf")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value
     */
    @JvmName("qcnqaxrvbiglgbsi")
    public suspend fun displayName(`value`: Output<String>) {
        this.displayName = value
    }

    /**
     * @param value
     */
    @JvmName("imfiinfbxafbgkly")
    public suspend fun gitRepository(`value`: Output<AcceleratorGitRepositoryArgs>) {
        this.gitRepository = value
    }

    /**
     * @param value
     */
    @JvmName("qcrdypasqwbjkyrb")
    public suspend fun iconUrl(`value`: Output<String>) {
        this.iconUrl = value
    }

    /**
     * @param value
     */
    @JvmName("qaplxmmwvmehjcpi")
    public suspend fun acceleratorTags(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.acceleratorTags = mapped
    }

    /**
     * @param values
     */
    @JvmName("agmdomgsdxnjqjro")
    public suspend fun acceleratorTags(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.acceleratorTags = mapped
    }

    /**
     * @param value
     */
    @JvmName("vsnrmgyefhwvfvlm")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value
     */
    @JvmName("gmnqdehvvberyyob")
    public suspend fun displayName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.displayName = mapped
    }

    /**
     * @param value
     */
    @JvmName("eoykayhsebgabxoy")
    public suspend fun gitRepository(`value`: AcceleratorGitRepositoryArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.gitRepository = mapped
    }

    /**
     * @param argument
     */
    @JvmName("tpjbbstytodlnvff")
    public suspend
    fun gitRepository(argument: suspend AcceleratorGitRepositoryArgsBuilder.() -> Unit) {
        val toBeMapped = AcceleratorGitRepositoryArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.gitRepository = mapped
    }

    /**
     * @param value
     */
    @JvmName("dfvbveynthytmawr")
    public suspend fun iconUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.iconUrl = mapped
    }

    internal fun build(): CustomizedAcceleratorPropertiesArgs = CustomizedAcceleratorPropertiesArgs(
        acceleratorTags = acceleratorTags,
        description = description,
        displayName = displayName,
        gitRepository = gitRepository ?: throw PulumiNullFieldException("gitRepository"),
        iconUrl = iconUrl,
    )
}
